@@ -2,6 +2,9 @@ from django.contrib import auth
 from django.core.exceptions import ValidationError
 from django.db import transaction
 from django.template.defaultfilters import slugify
+from firebase_token_generator import create_token
+from django.conf import settings
+
 
 from rest_framework import serializers
 from rest_framework import relations
@@ -127,20 +130,37 @@ class FeatureTypeField(relations.RelatedField):
 
 
 class UserSerializer(serializers.ModelSerializer):
-    """"Returns basic User fields"""
+    """Returns basic User fields"""
+
     class Meta:
         model = auth.get_user_model()
 
     def to_native(self, obj):
 
-        return {
+        json = {
             "id": obj.pk,
             "username": obj.username,
             "email": obj.email,
             "first_name": obj.first_name,
-            "last_name": obj.last_name
+            "last_name": obj.last_name,
+            "full_name": obj.get_full_name(),
+            "short_name": obj.get_short_name()
         }
 
+        # ensure this variable exists
+        secret = getattr(settings, 'FIREBASE_SECRET', None)
+        if secret:
+            # use firebase auth to provide auth variables to firebase security api
+            firebase_auth_payload = {
+                'id': obj.pk,
+                'username': obj.username,
+                'email': obj.email,
+                'is_staff': obj.is_staff
+            }
+            json['firebase_token'] = create_token(secret, firebase_auth_payload)
+
+        return json
+
 
 class AuthorField(relations.RelatedField):
     """This field manages the authors on a piece of content, and allows a "fatter"
