@@ -1,7 +1,6 @@
 from django.db import models
 
 from json_field import JSONField
-from bulbs.images.fields import RemoteImageField
 
 
 DEFAULT_VIDEO_OUTPUT = {
@@ -35,7 +34,6 @@ class Video(models.Model):
     name = models.CharField(max_length=255)
     data = JSONField(null=True, blank=True, help_text="This is JSON that is returned from an encoding job")
     sources = JSONField(null=True, blank=True, default=[], help_text="This is a JSON array of sources.")
-    poster = RemoteImageField(null=True, blank=True)
     poster_url = models.URLField(null=True, blank=True)
     status = models.IntegerField(choices=STATUSES, default=NOT_STARTED)
     job_id = models.IntegerField(null=True, blank=True, help_text="The zencoder job ID")
